@@ -8,6 +8,7 @@ from .exceptions import (
     ImproperlyConfiguredException,
     InternalServerException,
     NotAuthorizedException,
+    NotFoundException,
     PermissionDeniedException,
     ServiceUnavailableException,
     StarLiteException,
@@ -28,9 +29,13 @@ __all__ = [
     "AbstractAuthenticationMiddleware",
     "AuthenticationResult",
     "Body",
-    "CORSConfig",
     "Controller",
+    "CORSConfig",
+    "create_test_client",
+    "create_test_request",
+    "delete",
     "File",
+    "get",
     "HTTPException",
     "HttpMethod",
     "ImproperlyConfiguredException",
@@ -39,32 +44,29 @@ __all__ = [
     "MediaType",
     "MiddlewareProtocol",
     "NotAuthorizedException",
+    "NotFoundException",
     "OpenAPIConfig",
     "OpenAPIController",
     "OpenAPIMediaType",
     "Parameter",
     "Partial",
+    "patch",
     "PermissionDeniedException",
+    "post",
     "Provide",
+    "put",
     "Redirect",
     "Request",
     "RequestEncodingType",
     "Response",
     "ResponseHeader",
     "Route",
+    "route",
     "RouteHandler",
     "Router",
     "ServiceUnavailableException",
-    "StarLiteException",
     "Starlite",
+    "StarLiteException",
     "Stream",
     "TestClient",
-    "create_test_client",
-    "create_test_request",
-    "delete",
-    "get",
-    "patch",
-    "post",
-    "put",
-    "route",
 ]
